@@ -1,6 +1,7 @@
 import pytest
 
 from pycfmodel.model.resources.iam_user import IAMUser
+from pycfmodel.model.utils import OptionallyNamedPolicyDocument
 
 
 @pytest.fixture()
@@ -37,5 +38,11 @@ def test_policies(iam_user):
     assert iam_user.Properties.Policies[0].PolicyName == "BadPolicy"
 
 
+def test_iam_role_policy_documents(iam_user):
+    assert iam_user.policy_documents == [
+        OptionallyNamedPolicyDocument(name="BadPolicy", policy_document=iam_user.Properties.Policies[0].PolicyDocument)
+    ]
+
+
 def test_credential_check(iam_user):
     assert iam_user.has_hardcoded_credentials()
